<p:declare-step xmlns:p="http://www.w3.org/ns/xproc" 
	name="run-epub" version="1.0">
	<p:input port="source"/>
	<p:input port="parameters" kind="parameter"/>
	<p:output port="result" sequence="true">
		<p:pipe step="generate-opf" port="result"/>
		<p:pipe step="generate-xhtml" port="result"/>
		<p:pipe step="generate-ncx" port="result"/>
		<p:pipe step="generate-container" port="result"/>
	</p:output>
	
	<!-- ============================================================= -->
	<!-- REQUIRED COMMAND LINE OPTIONS -->
	<!-- outdir = path and name of output directory;
		Example: /home/usr/epub/doi -->
	<!-- outfile = name of the output xhtml file;
		Example: kelly.xml -->
	<!-- ============================================================= -->
	<p:option name="outdir"/>
	<p:option name="outfile"/>
	
	
	<p:uuid match="/article/@dtd-version" version="4" name="make-uuid"/>	
	
		
	<p:store method="text" name="out">		
		<p:input port="source">
			<p:inline><x>application/epub+zip</x></p:inline>
		</p:input>
		<p:with-option name="href" select="concat($outdir,'/mimetype')"/>
		<p:with-option name="media-type" select="text"/>
	</p:store>
	
	<p:xslt name="epub-filter">
		<p:input port="source">
			<p:pipe step="make-uuid" port="result"/>
		</p:input>
		<p:input port="stylesheet">
			<p:document href="epub-filter.xsl"/>
		</p:input>
		<p:input port="parameters">
			<p:empty/>
		</p:input>
	</p:xslt>
	
	
	<!-- ===== CONTAINER ===== -->
	<p:group name="generate-container">
		<p:output port="result">
			<p:pipe step="store-container" port="result"/>
		</p:output>
		<p:xslt name="ncx">
			<p:input port="source">
				<p:pipe step="epub-filter" port="result"/>		
			</p:input>
			<p:input port="stylesheet">
				<p:document href="container.xsl"/>
			</p:input>
			<p:input port="parameters">
				<p:empty/>
			</p:input>		
		</p:xslt>
		<p:store name="store-container">
			<p:with-option name="href" select="concat($outdir,'/META-INF/container.xml')"/>
			<p:with-option name="indent" select="'true'"/>
		</p:store>
	</p:group>
	
	
	<!-- ===== OPF ===== -->
	<p:group name="generate-opf">
		<p:output port="result">
			<p:pipe step="store-opf" port="result"/>
		</p:output>
		<p:xslt name="opf">
			<p:input port="source">
				<p:pipe step="epub-filter" port="result"/>
			</p:input>
			<p:input port="stylesheet">
				<p:document href="opf.xsl"/>
			</p:input>
			<p:input port="parameters">
				<p:empty/>
			</p:input>
			<p:with-param name="outfile" select="$outfile"/>
		</p:xslt>
		<p:store name="store-opf">
			<p:with-option name="href" select="concat($outdir,'/OPS/epb.opf')"/>
			<p:with-option name="indent" select="'true'"/>
		</p:store>
	</p:group>
	
	<!-- ===== NCX ===== -->
	<p:group name="generate-ncx">
		<p:output port="result">
			<p:pipe step="store-ncx" port="result"/>
		</p:output>
		<p:xslt name="ncx">
			<p:input port="source">
				<p:pipe step="epub-filter" port="result"/> 
			</p:input>
			<p:input port="stylesheet">
				<p:document href="ncx.xsl"/>
			</p:input>
			<p:input port="parameters">
				<p:empty/>
			</p:input>		
			<p:with-param name="outfile" select="$outfile"/>
		</p:xslt>
		<p:store name="store-ncx">			
			<p:with-option name="href" select="concat($outdir,'/OPS/epb.ncx')"/>
			<p:with-option name="indent" select="'true'"/>
		</p:store>
	</p:group>
	
	<!-- ===== XHTML ==== -->
	<p:group name="generate-xhtml">
		<p:output port="result">
			<p:pipe step="store-xhtml" port="result"/>
		</p:output>
		<p:xslt name="citation-prep">
			<p:input port="source">
				<p:pipe step="epub-filter" port="result"/>		
			</p:input>
			<p:input port="stylesheet">
				<p:document href="jpub3-PMCcit.xsl"/>			
			</p:input>
			<p:input port="parameters">
				<p:empty/>
			</p:input>
		</p:xslt>		
		<p:xslt name="xhtml">
			<p:input port="source">
				<p:pipe step="citation-prep" port="result"/>
			</p:input>
			<p:input port="stylesheet">
				<p:document href="xhtml.xsl"/>
			</p:input>
			<p:input port="parameters">
				<p:empty/>
			</p:input>		
		</p:xslt>
		<p:store name="store-xhtml">
			<p:with-option name="href" select="concat($outdir,'/OPS/', $outfile)"/>
			<p:with-option name="indent" select="'true'"/>
		</p:store>
	</p:group>
	
	
	<p:store method="text" name="css">		
		<p:input port="source">
			<p:inline><css>div.meta {font-family:sans-serif;}
div.meta > div.citation {font-size:85%}
.article-title {font-weight:bold;
	font-size:130%;}
div.meta > div.contrib {font-size:85%}
div.meta-permissions {font-size:85%;
	margin-top: 5px;}
div.article-id {font-size:75%}
div.pub-date{font-size:75%;}
div.abstract {margin-top:10px;}
div.boxed-text {border: 1px solid;}
div.object-permissions {font-size:85%;
	margin-top: 5px;}
span.title {font-weight:bold;}
.overline {text-decoration: overline}
.roman {font-style: normal}
.sans-serif {font-family: sans-serif}
.sc {font-variant: small-caps}
.strike {text-decoration: line-through}
div.p {text-indent:15px;
	margin-top: 0; 
	margin-bottom:5px;}
h1 {font-size:125%;
	font-weight:bold;
	margin-bottom:3px;}
h2 {font-size:120%;
	font-weight:bold;
	margin-bottom:3px;}
h3 {font-size:115%;
	font-weight:bold;
	margin-bottom:3px;}
h4 {font-size:110%;
	font-weight:bold;
	margin-bottom:3px;}
h5 {font-size:105%;
	font-weight:bold;
	margin-bottom:3px;}
h6 {font-weight:bold;
	margin-bottom:3px;}
.simple-list {list-style-type: none;}
.alpha-lower {list-style-type: lower-alpha;}
.alpha-upper {list-style-type: upper-alpha;}
.roman-lower {list-style-type: lower-roman;}
.roman-upper {list-style-type: upper-roman;}</css></p:inline>
		</p:input>
		<p:with-option name="href" select="concat($outdir,'/OPS/jpub-epub.css')"/>
		<p:with-option name="media-type" select="text"/>
	</p:store>
	
	
</p:declare-step>