<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns="http://www.idpf.org/2007/opf"
	xmlns:opf="http://www.idpf.org/2007/opf"
	xmlns:dc="http://purl.org/dc/elements/1.1/"
	xmlns:xlink="http://www.w3.org/1999/xlink" 
	exclude-result-prefixes="xlink">
	
	<xsl:include href="mimetype.xsl"/>
	
	<xsl:output name="opf" method="xml" indent="yes"/>	
		
	<xsl:variable name="supported-mimetypes">
		<m type="image/gif"/>
		<m type="image/jpeg"/>
		<m type="image/png"/>
		<m type="image/svg+xml"/>
		<m type="text/css"/>
		<m type="application/xml"/>
		<m type="application/x-dtbncx+xml"/>
	</xsl:variable>
	
	<xsl:param name="outfile"/>
	
	<!-- REPLACE WITH UUID -->
	<!--<xsl:variable name="unique-id">
		<xsl:choose>
			<xsl:when test="/article/front/article-meta/article-id[@pub-id-type='doi']">
				<xsl:value-of select="/article/front/article-meta/article-id[@pub-id-type='doi']"/>
			</xsl:when>
			<xsl:when test="/article/front/article-meta/article-id[@pub-id-type='pmcid']">
				<xsl:value-of select="/article/front/article-meta/article-id[@pub-id-type='pmcid']"/>
			</xsl:when>
			<xsl:when test="/article/front/article-meta/article-id[@pub-id-type='pmid']">
				<xsl:value-of select="/article/front/article-meta/article-id[@pub-id-type='pmid']"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="/article/front/article-meta/article-id[1]/@pub-id-type"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>-->
	
	<xsl:template match="/">
		<!--<xsl:result-document href="{$pub-id}/OEBPS/epb.opf" format="opf">-->
			<package xmlns="http://www.idpf.org/2007/opf" version="2.0" unique-identifier="UUID">
				<xsl:call-template name="make-metadata"/>
				<xsl:call-template name="make-manifest"/>
				<xsl:call-template name="make-spine"/>
			</package>			
		<!--</xsl:result-document>-->
	</xsl:template>
	
	<!-- ======================================= -->
	<!-- TEMPLATE NAME: make-metadata -->
	<!-- Writes metadata element, convert JATS elements to 
		Dublin Core meta elements -->
	<!-- ======================================= -->
	<xsl:template name="make-metadata" >
		<metadata>
			<xsl:apply-templates select="/article/front/article-meta/title-group" mode="dc"/>
			<xsl:apply-templates select="/article/front/article-meta/contrib-group" mode="dc"/>
			<xsl:apply-templates select="/article/front/article-meta/kwd-group" mode="dc"/>
			<xsl:apply-templates select="/article/front/article-meta/abstract[1]" mode="dc"/>
			<xsl:apply-templates select="/article/front/article-meta/publisher" mode="dc"/>
			<!-- pub-date -->
			<xsl:choose>
				<xsl:when test="/article/front/article-meta/pub-date[@pub-type='ppub']">
					<xsl:apply-templates select="/article/front/article-meta/pub-date[@pub-type='ppub']" mode="dc"/>
				</xsl:when>
				<xsl:when test="/article/front/article-meta/pub-date[@pub-type='epub']">
					<xsl:apply-templates select="/article/front/article-meta/pub-date[@pub-type='epub']" mode="dc"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates select="/article/front/article-meta/pub-date[1]" mode="dc"/>
				</xsl:otherwise>
			</xsl:choose>
			<dc:type>
				<xsl:value-of select="/article/@article-type"/>
			</dc:type>
			<dc:identifier id="UUID"><xsl:value-of select="/article/@dtd-version"/></dc:identifier>
			<xsl:apply-templates select="/article/front/article-meta/article-id" mode="dc"/>
			<xsl:apply-templates select="/article/front/journal-meta/journal-title-group" mode="dc"/>
			<dc:language>
				<xsl:value-of select="/article/@xml:lang"/>
			</dc:language>
			<xsl:apply-templates select="/article/front/article-meta/permissions" mode="dc"/>
		</metadata>
	</xsl:template>
	
	<!-- ======================================= -->
	<!-- TEMPLATE MATCH: title-group -->
	<!-- MODE: dc -->
	<!-- ======================================= -->
	<xsl:template match="title-group" mode="dc">
		<dc:title>
			<xsl:apply-templates select="article-title" mode="dc"/>
			<xsl:if test="subtitle">
				<xsl:text>: </xsl:text>
				<xsl:apply-templates select="subtitle" mode="dc"/>
			</xsl:if>
		</dc:title>
	</xsl:template>
	
	<xsl:template match="article-title" mode="dc">
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="subtitle" mode="dc">
		<xsl:apply-templates/>
	</xsl:template>
	
	
	<!-- ======================================= -->
	<!-- TEMPLATE MATCH: contrib-group -->
	<!-- MODE: dc -->
	<!-- ======================================= -->
	<xsl:template match="contrib-group" mode="dc">
		<xsl:for-each select="contrib">
			<dc:contributor>
				<xsl:if test="@contrib-type">
					<xsl:attribute name="opf:role">
						<xsl:choose>
							<xsl:when test="@contrib-type='author'">
								<xsl:text>aut</xsl:text>
							</xsl:when>
							<xsl:when test="@contrib-type='editor'">
								<xsl:text>edt</xsl:text>
							</xsl:when>
							<xsl:when test="@contrib-type='illus'">
								<xsl:text>ill</xsl:text>
							</xsl:when>
							<xsl:when test="@contrib-type='reviewer'">
								<xsl:text>rev</xsl:text>
							</xsl:when>
							<xsl:when test="@contrib-type='translator'">
								<xsl:text>trl</xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:message>UNRECOGNIZED CONTRIBUTOR TYPE [<xsl:value-of select="@contrib-type"/>]</xsl:message>
								<xsl:text>oth</xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</xsl:if>
				<xsl:choose>
					<xsl:when test="anonymous">
						<xsl:text>Anonymous</xsl:text>
					</xsl:when>
					<xsl:when test="collab or string-name">
						<xsl:apply-templates select="collab | string-name"/>
					</xsl:when>
					<xsl:when test="name">
						<xsl:if test="name/prefix">
							<xsl:value-of select="name/prefix"/>
							<xsl:text> </xsl:text>
						</xsl:if>
						<xsl:if test="name/given-names">
							<xsl:value-of select="name/given-names"/>
							<xsl:text> </xsl:text>
						</xsl:if>
						<xsl:if test="name/surname">
							<xsl:value-of select="name/surname"/>
						</xsl:if>
						<xsl:if test="name/suffix">							
							<xsl:text>, </xsl:text>
							<xsl:value-of select="name/suffix"/>
						</xsl:if>
					</xsl:when>
				</xsl:choose>
			</dc:contributor>
		</xsl:for-each>
	</xsl:template>
	
	
	<!-- ======================================= -->
	<!-- ======================================= -->
	<xsl:template match="kwd-group" mode="dc">
		<dc:subject>
			<xsl:for-each select="kwd">
				<xsl:apply-templates/>
				<xsl:if test="following-sibling::kwd">
					<xsl:text>, </xsl:text>
				</xsl:if>
			</xsl:for-each>
		</dc:subject>
	</xsl:template>
	
	
	<!-- ======================================= -->
	<!-- ======================================= -->
	<xsl:template match="abstract" mode="dc">
		<dc:description>
			<xsl:apply-templates mode="dc"/>
		</dc:description>
	</xsl:template>
	
	<xsl:template match="abstracct/p" mode="dc">
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="publisher" mode="dc">
		<dc:publisher>
			<xsl:value-of select="publisher-name"/>
			<xsl:if test="publisher-loc">
				<xsl:text>, </xsl:text>
				<xsl:value-of select="publisher-loc"/>
			</xsl:if>
		</dc:publisher>
	</xsl:template>
	
	
	<xsl:template match="pub-date" mode="dc">
		<dc:date opf:event="publication">
			<xsl:value-of select="year"/>
			<xsl:if test="month">
				<xsl:text>-</xsl:text>
				<xsl:value-of select="if (string-length(month)=2) then (month) else (concat('0',month))"/>
				<xsl:if test="day">
					<xsl:text>-</xsl:text>
					<xsl:value-of select="if (string-length(day)=2) then (day) else (concat('0',day))"/>
				</xsl:if>
			</xsl:if>
		</dc:date>
	</xsl:template>
	

	<xsl:template match="article-id" mode="dc">
		<dc:identifier opf:scheme="{@pub-id-type}">
			<xsl:apply-templates/>
		</dc:identifier>
	</xsl:template>
	
	
	<xsl:template match="journal-title-group" mode="dc">
		<dc:source>
			<xsl:value-of select="journal-title"/>
			<xsl:if test="journal-subtitle">
				<xsl:text>: </xsl:text>
				<xsl:value-of select="journal-subtitle"/>
			</xsl:if>
		</dc:source>
	</xsl:template>
	
	<xsl:template match="permissions" mode="dc">
		<dc:rights>
			<xsl:choose>
				<xsl:when test="copyright-statement">
					<xsl:value-of select="copyright-statement"/>
				</xsl:when>
				<xsl:when test="copyright-holder">
					<xsl:if test="copyright-year">
						<xsl:value-of select="copyright-year"/>
						<xsl:text> </xsl:text>
					</xsl:if>
					<xsl:value-of select="copyright-holder"/>
				</xsl:when>
			</xsl:choose>
			<xsl:if test="license-p">
				<xsl:value-of select="license-p"/>
			</xsl:if>
		</dc:rights>
	</xsl:template>
	
	
	
	<!-- ======================================= -->
	<!-- ======================================= -->
	<xsl:template name="make-manifest">
		<manifest>
			<xsl:for-each select="//article">
				<xsl:call-template name="make-manifest-item"/>
			</xsl:for-each>
			
			<xsl:for-each select="//graphic | //media | inline-graphic">
				<xsl:variable name="mimetype">
					<xsl:call-template name="get_mimetype">
						<xsl:with-param name="source" select="@xlink:href"/>
					</xsl:call-template>
				</xsl:variable>
				<item id="{if (@id) then (@id) else (generate-id())}" href="{@xlink:href}" media-type="{$mimetype}">	
					<xsl:if test="not($supported-mimetypes/*[@type=$mimetype])">
						<xsl:message>WARNING: File type <xsl:value-of select="$mimetype"/> not supported.</xsl:message>
						<xsl:comment>WARNING: File type <xsl:value-of select="$mimetype"/> not supported.</xsl:comment>
					</xsl:if>
				</item>				
			</xsl:for-each>
			
			<!-- CSS file -->
			<item id="main-css" href="jpub-epub.css" media-type="text/css"/>
			
			<!-- Table of contents file -->
			<item id="ncx" href="epb.ncx" media-type="application/x-dtbncx+xml"/>
			
		</manifest>
	</xsl:template>
	
	
	<xsl:template name="make-manifest-item">
		<item id="{if (@id) then (@id) else (generate-id(.))}" href="{$outfile}" media-type="application/xhtml+xml"/>
	</xsl:template>
	
	
	<!-- ======================================= -->
	<!-- ======================================= -->
	<xsl:template name="make-spine">
		<spine toc="ncx">
			<xsl:for-each select="/article">
				<xsl:call-template name="make-spine-itemref"/>
			</xsl:for-each>
		</spine>
	</xsl:template>
	
	<xsl:template name="make-spine-itemref">
		<itemref idref="{if (@id) then (@id) else (generate-id(.))}" linear="yes"/>
	</xsl:template>

</xsl:stylesheet>
