<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0"
    xmlns="http://www.w3.org/1999/xhtml" 
    xmlns:mml="http://www.w3.org/1998/Math/MathML"
    xmlns:xlink="http://www.w3.org/1999/xlink"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"	
    exclude-result-prefixes="xlink mml">
        
    <xsl:include href="mimetype.xsl"/>
        
    <xsl:variable name="supported-mimetypes">
        <m type="image/gif"/>
        <m type="image/jpeg"/>
        <m type="image/png"/>
        <m type="image/svg+xml"/>
        <m type="text/css"/>
        <m type="application/xml"/>
        <m type="application/x-dtbncx+xml"/>
    </xsl:variable>
    
    <xsl:output method="xml"
        doctype-public="-//NLM//DTD Journal Archiving and Interchange DTD v3.0 20080202//EN"
        doctype-system="archivearticle3.dtd"
        indent="no"/>
    
    <xsl:template match="/">
        <xsl:apply-templates mode="copy"/>
    </xsl:template>
    
    <xsl:template match="@*|node()" mode="copy">
        <xsl:copy>
            <xsl:apply-templates select="@*|node()" mode="#current"/>
        </xsl:copy>
    </xsl:template>
    
    <xsl:template match="node()" mode="add-specuse">
        <xsl:copy>
            <xsl:attribute name="specific-use" select="'epub-xhtml'"/>
            <xsl:apply-templates select="@*|node()" mode="copy"/>
        </xsl:copy>
    </xsl:template>
    
    <!-- ============================================================= -->
    <!-- ALTERNATIVES -->
    <!-- ============================================================= -->
    <xsl:template match="alternatives" mode="copy">
        <xsl:variable name="object-to-use" as="element()*">
            <xsl:call-template name="find-first-cmt">
                <xsl:with-param name="nodes" select="*"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:copy>
        <xsl:choose>
            <xsl:when test="$object-to-use">
                <xsl:apply-templates select="$object-to-use" mode="copy"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:comment>WARNING: No file of core media type specified.</xsl:comment>
                <xsl:apply-templates mode="copy"/>                
            </xsl:otherwise>
        </xsl:choose>
        </xsl:copy>
    </xsl:template>
    
    
    <!-- ============================================================= -->
    <!-- Find first core media type -->
    <!-- find-first-cmt-->
    <!-- ============================================================= -->
    <xsl:template name="find-first-cmt">
        <xsl:param name="nodes"/>
        <xsl:if test="$nodes">
            <xsl:choose>
                <xsl:when test="local-name($nodes[1])='graphic'
                    or local-name($nodes[1])='inline-graphic'
                    or local-name($nodes[1])='inline-supplementary-material'
                    or local-name($nodes[1])='media'">
                    <xsl:variable name="mimetype">
                        <xsl:call-template name="get_mimetype">
                            <xsl:with-param name="source" select="$nodes[1]/@xlink:href"/>
                        </xsl:call-template>
                    </xsl:variable>
                    <xsl:choose>
                        <xsl:when test="$supported-mimetypes/*[@type=$mimetype]">
                            <xsl:apply-templates select="$nodes[1]" mode="add-specuse"/>
                            <xsl:apply-templates select="$nodes[position() gt 1]" mode="copy"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:apply-templates select="$nodes[1]" mode="copy"/>
                            <xsl:call-template name="find-first-cmt">
                                <xsl:with-param name="nodes" select="$nodes[position() gt 1]"/>
                            </xsl:call-template>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:when>
                <xsl:when test="local-name($nodes[1])='chem-struct'
                    or local-name($nodes[1])='mml:math'
                    or local-name($nodes[1])='private-char'
                    or local-name($nodes[1])='supplementary-material'
                    or local-name($nodes[1])='tex-math'">
                    <xsl:apply-templates select="$nodes[1]" mode="copy"/>
                    <xsl:call-template name="find-first-cmt">
                        <xsl:with-param name="nodes" select="$nodes[position() gt 1]"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:when test="local-name($nodes[1])='array'
                    or local-name($nodes[1])='textual-form'
                    or local-name($nodes[1])='preformat'
                    or local-name($nodes[1])='table'">
                    <xsl:apply-templates select="$nodes[1]" mode="add-specuse"/>
                    <xsl:apply-templates select="$nodes[position() gt 1]" mode="copy"/>
                </xsl:when>
            </xsl:choose>
        </xsl:if>
    </xsl:template>
   
    
</xsl:stylesheet>