<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0"
	xmlns="http://www.w3.org/1999/xhtml" 
	xmlns:mml="http://www.w3.org/1998/Math/MathML"
	xmlns:xlink="http://www.w3.org/1999/xlink"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"	
	xmlns:xs="http://www.w3.org/2001/XMLSchema"
	exclude-result-prefixes="xlink mml xs">
	
	<xsl:include href="mimetype.xsl"/>
	
	<xsl:output name="xhtml"
		method="xhtml" 
		doctype-public="-//W3C//DTD XHTML 1.1//EN"
		doctype-system="http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd"
		encoding="utf-8" indent="no"/>
	
	<xsl:variable name="css" select="'jpub-epub.css'"/>
	
	<xsl:variable name="supported-mimetypes">
		<m type="image/gif"/>
		<m type="image/jpeg"/>
		<m type="image/png"/>
		<m type="image/svg+xml"/>
		<m type="text/css"/>
		<m type="application/xml"/>
		<m type="application/x-dtbncx+xml"/>
	</xsl:variable>
	
	<xsl:strip-space elements="*"/>
	
	<xsl:preserve-space
		elements="abbrev abbrev-journal-title access-date addr-line aff 
		alt-text alt-title article-id article-title attrib 
		award-id bold chapter-title chem-struct collab comment 
		compound-kwd-part conf-acronym conf-date conf-loc conf-name 
		conf-num conf-sponsor conf-theme copyright-holder 
		copyright-statement copyright-year corresp country 
		date-in-citation day def-head degrees disp-formula 
		edition elocation-id email etal ext-link fax fpage 
		funding-source funding-statement given-names glyph-data gov 
		inline-formula inline-supplementary-material institution 
		isbn issn issue issue-id issue-part issue-sponsor 
		issue-title italic journal-id journal-subtitle 
		journal-title kwd label license-p long-desc lpage 
		meta-name meta-value mixed-citation monospace month 
		named-content object-id on-behalf-of overline p 
		page-range part-title patent phone prefix preformat 
		price principal-award-recipient principal-investigator 
		product pub-id publisher-loc publisher-name 
		related-article related-object role roman sans-serif 
		sc season self-uri series series-text series-title 
		sig sig-block size source speaker std strike 
		string-conf string-date string-name styled-content sub 
		subject subtitle suffix sup supplement surname target 
		td term term-head tex-math textual-form th time-stamp 
		title trans-source trans-subtitle trans-title underline 
		unstructured-kwd-group uri verse-line volume volume-id 
		volume-series x xref year 		
		mml:annotation mml:ci mml:cn mml:csymbol mml:mi mml:mn 
		mml:mo mml:ms mml:mtext"/>
	
	<xsl:variable name="citation">
		<xsl:value-of select="/article/front/journal-meta//journal-title"/>
		<xsl:text> </xsl:text>
		<xsl:if test="/article/front/article-meta/volume">
			<xsl:value-of select="/article/front/article-meta/volume"/>
		</xsl:if>
		<xsl:if test="/article/front/article-meta/issue">
			<xsl:value-of select="concat('(',/article/front/article-meta/issue,')')"/>
		</xsl:if>
		<xsl:choose>
			<xsl:when test="/article/front/article-meta/fpage">
				<xsl:text>: </xsl:text>
				<xsl:value-of select="/article/front/article-meta/fpage"/>
				<xsl:if test="/article/front/article-meta/lpage">
					<xsl:text>-</xsl:text>
					<xsl:value-of select="/article/front/article-meta/lpage"/>
				</xsl:if>
			</xsl:when>
			<xsl:when test="/article/front/article-meta/elocation-id">
				<xsl:text>: </xsl:text>
				<xsl:value-of select="/article/front/article-meta/elocation-id"/>
			</xsl:when>
		</xsl:choose>
	</xsl:variable>
	
	<xsl:template match="article">
		<html xml:lang="en"
			xmlns="http://www.w3.org/1999/xhtml" >
			<!-- HTML header -->
			<xsl:call-template name="make-html-header"/>
			<body>
				<div class="meta">
					<xsl:if test="normalize-space($citation)">
						<div class="citation">
							<xsl:value-of select="$citation"/>
						</div>
					</xsl:if>
					<xsl:apply-templates select="front/article-meta/title-group, front/article-meta/contrib-group,
						front/article-meta/permissions, front/article-meta/article-id[lower-case(@pub-id-type)='doi'],
						front/article-meta/pub-date"/>
					<xsl:choose>
						<xsl:when test="count(front/article-meta/abstract) eq 1">
							<xsl:apply-templates select="front/article-meta/abstract"/>
						</xsl:when>
						<xsl:when test="count(front/article-meta/abstract) gt 1">
							<xsl:apply-templates select="front/article-meta/abstract[not(@abstract-type)][1]"/>
						</xsl:when>
					</xsl:choose>						
				</div>
				
				<div class="body">
					<xsl:apply-templates select="body"/>
				</div>
				
				<div class="back">
					<xsl:apply-templates select="back"/>
				</div>
			</body>
		</html>
	</xsl:template>	
	
	<xsl:template name="make-html-header">
		<head>
			<title>
				<xsl:choose>
					<xsl:when test="normalize-space($citation)">
						<xsl:value-of select="$citation"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="/article/front/article-meta//article-title"/>
					</xsl:otherwise>
				</xsl:choose>				
			</title>
			<link rel="stylesheet" type="text/css" href="{$css}"/>
		</head>
	</xsl:template>
	
	<xsl:template match="title-group">
		<div class="title">
			<xsl:apply-templates select="article-title, subtitle"/>
		</div>
	</xsl:template>
	
	<xsl:template match="contrib-group">
		<div class="contrib">
			<xsl:apply-templates/>
		</div>
	</xsl:template>
	
	<xsl:template match="permissions">
		<div class="{if (parent::article-meta) then ('meta-permissions') else ('object-permissions')}">
			<xsl:choose>
				<xsl:when test="copyright-statement">
					<xsl:apply-templates select="copyright-statement"/>
				</xsl:when>
				<xsl:when test="copyright-holder">
					<xsl:text>© </xsl:text>
					<xsl:if test="copyright-year">
						<xsl:apply-templates select="copyright-year"/>
						<xsl:text> </xsl:text>
					</xsl:if>
					<xsl:apply-templates select="copyright-holder"/>
				</xsl:when>
			</xsl:choose>
			<xsl:apply-templates select="license"/>
		</div>
	</xsl:template>
		
	<xsl:template match="pub-date">
		<xsl:if test="@pub-type='epub' or @pub-type='epub-ppub' or @pub-type='ppub'">		
			<div class="pub-date">
				<xsl:call-template name="pub-date-prefix">
					<xsl:with-param name="pub-type" select="@pub-type"/>
				</xsl:call-template>
				<xsl:apply-templates select="day, eason, month, year"/>
			</div>
		</xsl:if>	
	</xsl:template>
	
	<xsl:template name="pub-date-prefix">
		<xsl:param name="pub-type"/>
		<xsl:choose>
			<xsl:when test="$pub-type='ppub'">
				<xsl:text>Published in print: </xsl:text>
			</xsl:when>
			<xsl:when test="$pub-type='epub'">
				<xsl:text>Published online: </xsl:text>
			</xsl:when>
			<xsl:when test="epub-ppub">
				<xsl:text>Published in print and online: </xsl:text>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="month">
		<xsl:choose>
			<xsl:when test="number()=1">
				<xsl:text>Jan </xsl:text>
			</xsl:when>
			<xsl:when test="number()=2">
				<xsl:text>Feb </xsl:text>
			</xsl:when>
			<xsl:when test="number()=3">
				<xsl:text>Mar </xsl:text>
			</xsl:when>
			<xsl:when test="number()=4">
				<xsl:text>Apr </xsl:text>
			</xsl:when>
			<xsl:when test="number()=5">
				<xsl:text>May </xsl:text>
			</xsl:when>
			<xsl:when test="number()=6">
				<xsl:text>Jun </xsl:text>
			</xsl:when>
			<xsl:when test="number()=7">
				<xsl:text>Jul </xsl:text>
			</xsl:when>
			<xsl:when test="number()=8">
				<xsl:text>Aug </xsl:text>
			</xsl:when>
			<xsl:when test="number()=9">
				<xsl:text>Sep </xsl:text>
			</xsl:when>
			<xsl:when test="number()=10">
				<xsl:text>Oct </xsl:text>
			</xsl:when>
			<xsl:when test="number()=11">
				<xsl:text>Nov </xsl:text>
			</xsl:when>
			<xsl:when test="number()=12">
				<xsl:text>Dec </xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>	
	
	<xsl:template match="day">
		<xsl:apply-templates/>
		<xsl:text> </xsl:text>
	</xsl:template>
	
	<xsl:template match="article-id">
		<div class="article-id">
			<xsl:text>DOI: </xsl:text>
			<xsl:apply-templates/>
		</div>
	</xsl:template>
	
	<xsl:template match="article-title">
		<span class="article-title">
			<xsl:apply-templates/>
		</span>
	</xsl:template>
	
	<xsl:template match="subtitle">
		<span class="subtitle">
			<xsl:apply-templates/>
		</span>
	</xsl:template>
	
	<xsl:template match="abstract">
		<div class="abstract">
			<xsl:if test="not(title)">
				<span class="title">Abstract</span>
			</xsl:if>
			<xsl:apply-templates/>
		</div>
	</xsl:template>
	
	<xsl:template match="contrib">
		<xsl:apply-templates/>
		<xsl:if test="following-sibling::contrib or following-sibling::etal">
			<xsl:text>, </xsl:text>
		</xsl:if>
	</xsl:template>
	
		
	<!-- ============================================================= -->
	<!--  Writing a name                                               -->
	<!-- Copied from jpu3-html.xsl -->
	<!-- ============================================================= -->
	
	<!-- Called when displaying structured names in metadata         -->
	
	<xsl:template name="write-name" match="name">
		<xsl:apply-templates select="prefix" mode="inline-name"/>
		<xsl:apply-templates select="surname[../@name-style='eastern']"
			mode="inline-name"/>
		<xsl:apply-templates select="given-names" mode="inline-name"/>
		<xsl:apply-templates select="surname[not(../@name-style='eastern')]"
			mode="inline-name"/>
		<xsl:apply-templates select="suffix" mode="inline-name"/>
	</xsl:template>
	
	
	<xsl:template match="prefix" mode="inline-name">
		<xsl:apply-templates/>
		<xsl:if test="../surname | ../given-names | ../suffix">
			<xsl:text> </xsl:text>
		</xsl:if>
	</xsl:template>
	
	
	<xsl:template match="given-names" mode="inline-name">
		<xsl:apply-templates/>
		<xsl:if test="../surname[not(../@name-style='eastern')] | ../suffix">
			<xsl:text> </xsl:text>
		</xsl:if>
	</xsl:template>
	
	
	<xsl:template match="contrib/name/surname" mode="inline-name">
		<xsl:apply-templates/>
		<xsl:if test="../given-names[../@name-style='eastern'] | ../suffix">
			<xsl:text> </xsl:text>
		</xsl:if>
	</xsl:template>
	
	
	<xsl:template match="surname" mode="inline-name">
		<xsl:apply-templates/>
		<xsl:if test="../given-names[../@name-style='eastern'] | ../suffix">
			<xsl:text> </xsl:text>
		</xsl:if>
	</xsl:template>
	
	
	<xsl:template match="suffix" mode="inline-name">
		<xsl:apply-templates/>
	</xsl:template>
	
	<xsl:template match="body">
		<xsl:apply-templates>
			<xsl:with-param name="level" select="1" tunnel="yes"/>
		</xsl:apply-templates>
	</xsl:template>
	
	<xsl:template match="sec">
		<xsl:param name="level" tunnel="yes"/>
		<div class="sec">
			<xsl:apply-templates>
				<xsl:with-param name="level" select="$level + 1" tunnel="yes"/>
			</xsl:apply-templates>
		</div>
	</xsl:template>
	
	<xsl:template match="sec-meta">
		<div class="sec-meta">
			<xsl:apply-templates/>
		</div>
	</xsl:template>
	
	<xsl:template match="sec/title">
		<xsl:param name="level" tunnel="yes"/>
		<xsl:choose>
			<xsl:when test="$level ge 6">
				<h6>
					<xsl:apply-templates/>
				</h6>
			</xsl:when>
			<xsl:otherwise>
				<xsl:element name="{concat('h',$level)}">
					<xsl:apply-templates/>
				</xsl:element>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="p">
		<xsl:choose>
			<xsl:when test="*">
				<xsl:call-template name="write-p">
					<xsl:with-param name="nodes" select="node()"/>
					<xsl:with-param name="pass" select="'first'"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<p>
					<xsl:apply-templates/>
				</p>
			</xsl:otherwise>
		</xsl:choose>		
	</xsl:template>
	
	
	<xsl:template name="write-p">
		<xsl:param name="nodes"/>
		<xsl:param name="pass"/>
		<xsl:if test="$nodes">
			<xsl:choose>
				<xsl:when test="local-name($nodes[1])=''
					or local-name($nodes[1])='bold'
					or local-name($nodes[1])='italic'
					or local-name($nodes[1])='roman'
					or local-name($nodes[1])='sans-serif'
					or local-name($nodes[1])='monospace'
					or local-name($nodes[1])='sc'
					or local-name($nodes[1])='sub'
					or local-name($nodes[1])='sup'
					or local-name($nodes[1])='strike'
					or local-name($nodes[1])='underline'
					or local-name($nodes[1])='overline'
					or local-name($nodes[1])='ext-link'
					or local-name($nodes[1])='fn'
					or local-name($nodes[1])='xref'">
					<xsl:if test="$pass='first'">
						<p>
							<xsl:call-template name="p-content">
								<xsl:with-param name="nodes" select="$nodes"/>
							</xsl:call-template>
						</p>
					</xsl:if>
					<xsl:call-template name="write-p">
						<xsl:with-param name="nodes" select="$nodes[position() gt 1]"/>
						<xsl:with-param name="pass" select="'not-first'"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates select="$nodes[1]"/>
					<xsl:call-template name="write-p">
						<xsl:with-param name="nodes" select="$nodes[position() ne 1]"/>
						<xsl:with-param name="pass" select="'first'"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="p-content">
		<xsl:param name="nodes"/>
		<xsl:if test="$nodes">
			<xsl:if test="local-name($nodes[1])=''
				or local-name($nodes[1])='bold'
				or local-name($nodes[1])='italic'
				or local-name($nodes[1])='roman'
				or local-name($nodes[1])='sans-serif'
				or local-name($nodes[1])='monospace'
				or local-name($nodes[1])='sc'
				or local-name($nodes[1])='sub'
				or local-name($nodes[1])='sup'
				or local-name($nodes[1])='strike'
				or local-name($nodes[1])='underline'
				or local-name($nodes[1])='overline'
				or local-name($nodes[1])='ext-link'
				or local-name($nodes[1])='fn'
				or local-name($nodes[1])='xref'">
				<xsl:apply-templates select="$nodes[1]"/>
				<xsl:call-template name="p-content">
					<xsl:with-param name="nodes" select="$nodes[position() ne 1]"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
	</xsl:template>

	
	
	<xsl:template match="app">
		<div class="app">
			<xsl:apply-templates/>
		</div>
	</xsl:template>
	
	<xsl:template match="title">
		<span class="title">
			<xsl:apply-templates/>
		</span>
	</xsl:template>
	
	
	<!-- ============================================================= -->
	<!-- Text formatting templates -->
	<!-- ============================================================= -->
	
	<xsl:template match="bold">
		<b>
			<xsl:apply-templates/>
		</b>
	</xsl:template>
	
	<xsl:template match="italic">
		<i>
			<xsl:apply-templates/>
		</i>
	</xsl:template>
	
	<xsl:template match="sup | sub">
		<xsl:element name="{local-name(.)}">
			<xsl:apply-templates/>
		</xsl:element>
	</xsl:template>
	
	<xsl:template match="monospace">
		<tt>
			<xsl:apply-templates/>
		</tt>
	</xsl:template>
	
	<xsl:template match="underline">
		<span class="underline">
			<xsl:apply-templates/>
		</span>
	</xsl:template>
	
	<xsl:template match="overline">
		<span class="overline">
			<xsl:apply-templates/>
		</span>
	</xsl:template>
	
	<xsl:template match="roman">
		<span class="roman">
			<xsl:apply-templates/>
		</span>
	</xsl:template>
	
	<xsl:template match="sans-serif">
		<span class="sans-serif">
			<xsl:apply-templates/>
		</span>
	</xsl:template>
	
	<xsl:template match="sc">
		<span class="sc">
			<xsl:apply-templates/>
		</span>
	</xsl:template>
	
	<xsl:template match="strike">
		<span class="strike">
			<xsl:apply-templates/>
		</span>
	</xsl:template>
	
	<xsl:template match="preformat">
		<pre>
			<xsl:apply-templates/>
		</pre>
	</xsl:template>
	
	
	
	<!-- ============================================================= -->
	<!-- Page formatting -->
	<!-- ============================================================= -->
	
	<xsl:template match="break">
		<br />
	</xsl:template>
	
	<xsl:template match="hr">
		<hr />
	</xsl:template>
	
	
	<!-- ============================================================= -->
	<!-- Display objects -->
	<!-- ============================================================= -->
	
	<xsl:template match="disp-quote">
		<blockquote>
			<xsl:apply-templates/>
		</blockquote>
	</xsl:template>
	
	
	<xsl:template match="address">
		<xsl:choose>
			<!-- address appears as a sequence of inline elements if
				it has no addr-line and the parent may contain text -->
			<xsl:when test="not(addr-line) and
				(parent::collab | parent::p | parent::license-p |
				parent::named-content | parent::styled-content)">
				<xsl:call-template name="address-line"/>
			</xsl:when>
			<xsl:otherwise>
				<div class="address">
					<xsl:apply-templates/>
				</div>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	
	<xsl:template name="address-line">
		<!-- emits element children in a simple comma-delimited sequence -->
		<xsl:for-each select="*">
			<xsl:if test="position() &gt; 1">, </xsl:if>
			<xsl:apply-templates/>
		</xsl:for-each>
	</xsl:template>
	
	
	<xsl:template match="address/*">
		<p class="address-line">
			<xsl:apply-templates/>
		</p>
	</xsl:template>
	
	<xsl:template match="attrib">
		<p class="attrib">
			<xsl:apply-templates/>
		</p>
	</xsl:template>
	
	<!--<xsl:template match="caption">
		<div class="caption">
			<xsl:apply-templates/>
		</div>
	</xsl:template>-->
	
	<xsl:template match="boxed-text">
		<div class="boxed-text">
			<xsl:apply-templates/>
		</div>
	</xsl:template>
	
	<xsl:template match="list[@list-type='bullet' or @list-type='simple' or not(@list-type)]">
		<ul>
			<xsl:if test="@list-type='simple'">
				<xsl:attribute name="style" select="'list-style-type: none;'"/>
			</xsl:if>
			<xsl:apply-templates select="list-item"/>
		</ul>
	</xsl:template>
	
	
	<xsl:template match="list">
		<ol class="{@list-type}">
			<xsl:apply-templates select="list-item"/>
		</ol>
	</xsl:template>
	
	<xsl:template match="list-item">
		<li>
			<xsl:apply-templates/>
		</li>
	</xsl:template>
	
	<xsl:template match="list-item/p">
		<p>
			<xsl:apply-templates/>
		</p>
	</xsl:template>
	
	
	<!-- ============================================================= -->
	<!-- Definition list -->
	<!-- ============================================================= -->
	
	<xsl:template match="def-list">
		<dl>
			<xsl:apply-templates/>
		</dl>
	</xsl:template>
	
	<xsl:template match="term-head">
		<dt><b><xsl:apply-templates/></b></dt>
	</xsl:template>
	
	<xsl:template match="def-head">
		<dd><b><xsl:apply-templates/></b></dd>
	</xsl:template>
	
	<xsl:template match="term">
		<dt>
			<xsl:apply-templates/>
		</dt>
	</xsl:template>
	
	<xsl:template match="def">
		<dd>
			<xsl:apply-templates/>
		</dd>
	</xsl:template>
	
	
	<!-- ============================================================= -->
	<!-- Figure -->
	<!-- ============================================================= -->

	<xsl:template match="fig">
		<div class="fig">
			<xsl:if test="@id">
				<xsl:attribute name="id" select="@id"/>
			</xsl:if>
			<xsl:apply-templates/>
		</div>
	</xsl:template>
	
	<xsl:template match="fig/label">
		<div class="fig-label">
			<xsl:apply-templates/>
			<xsl:if test="following-sibling::caption/title">
				<xsl:if test="not(ends-with(.,'.')) and not(ends-with(.,':'))">
					<xsl:text>. </xsl:text>
				</xsl:if>
				<xsl:apply-templates select="following-sibling::caption/title"/>
			</xsl:if>
		</div>
	</xsl:template>
	
	<xsl:template match="fig/caption">
		<xsl:apply-templates select="p"/>
	</xsl:template>
	
	
	<!-- ============================================================= -->
	<!-- Graphic -->
	<!-- ============================================================= -->
	<xsl:template match="graphic">
		<xsl:variable name="mimetype">
			<xsl:choose>
				<xsl:when test="@mime-subtype">
					<xsl:value-of select="@mime-subtype"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="get_mimetype">
						<xsl:with-param name="source" select="@xlink:href"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<img src="{@xlink:href}">
			<xsl:if test="@id">
				<xsl:attribute name="id" select="@id"/>
			</xsl:if>
			<xsl:attribute name="alt">
				<xsl:choose>
					<xsl:when test="../alt-text">
						<xsl:value-of select="../alt-text"/>
					</xsl:when>
					<xsl:when test="../label">
						<xsl:value-of select="../label"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>[Image: </xsl:text>
						<xsl:value-of select="@xlink:href"/>
						<xsl:text>]</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:attribute>
			<xsl:if test="not($supported-mimetypes/*[@type=$mimetype])">
				<xsl:comment>WARNING: File type <xsl:value-of select="$mimetype"/> not supported.</xsl:comment>
			</xsl:if>
		</img>
	</xsl:template>
	
	<xsl:template match="alt-text"/>
	
	<xsl:template match="label">
		<span class="label">
			<xsl:apply-templates/>
		</span>
	</xsl:template>
	
	<xsl:template match="object-id">
		<span class="object-id">
			<xsl:apply-templates/>
		</span>
	</xsl:template>
		
		
	<!-- ============================================================= -->
	<!-- ALTERNATIVES -->
	<!-- ============================================================= -->
	<xsl:template match="alternatives">			
		<xsl:variable name="object-to-use" as="element()*">
			<xsl:call-template name="find-first-cmt">
				<xsl:with-param name="nodes" select="*"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:choose>
			<xsl:when test="$object-to-use">
				<xsl:apply-templates select="$object-to-use"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates select="*[1]"/>
				<xsl:comment>WARNING: No file of core media type specified.</xsl:comment>
			</xsl:otherwise>
		</xsl:choose>		
	</xsl:template>
	
	
	<!-- ============================================================= -->
	<!-- Find first core media type -->
	<!-- find-first-cmt-->
	<!-- ============================================================= -->
	<xsl:template name="find-first-cmt">
		<xsl:param name="nodes"/>
		<xsl:if test="$nodes">
			<xsl:choose>
				<xsl:when test="local-name($nodes[1])='graphic'
					or local-name($nodes[1])='inline-graphic'
					or local-name($nodes[1])='inline-supplementary-material'
					or local-name($nodes[1])='media'">
					<xsl:variable name="mimetype">
						<xsl:call-template name="get_mimetype">
							<xsl:with-param name="source" select="$nodes[1]/@xlink:href"/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:choose>
						<xsl:when test="$supported-mimetypes/*[@type=$mimetype]">
							<!--<xsl:apply-templates select="$nodes[1]"/>-->
							<xsl:copy-of select="$nodes[1]"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="find-first-cmt">
								<xsl:with-param name="nodes" select="$nodes[position() gt 1]"/>
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:when test="local-name($nodes[1])='chem-struct'
					or local-name($nodes[1])='mml:math'
					or local-name($nodes[1])='private-char'
					or local-name($nodes[1])='supplementary-material'
					or local-name($nodes[1])='tex-math'">
					<xsl:call-template name="find-first-cmt">
						<xsl:with-param name="nodes" select="$nodes[position() gt 1]"/>
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="local-name($nodes[1])='array'
					or local-name($nodes[1])='textual-form'
					or local-name($nodes[1])='preformat'
					or local-name($nodes[1])='table'">
					<!--<xsl:apply-templates select="$nodes[1]"/>-->
					<xsl:copy-of select="$nodes[1]"/>
				</xsl:when>
			</xsl:choose>
		</xsl:if>
	</xsl:template>
	
	
	<!-- ============================================================= -->
	<!--  TABLES                                                       -->
	<!-- ============================================================= -->
	<xsl:template match="table-wrap">
		<div class="table">
			<xsl:if test="@id">
				<xsl:attribute name="id" select="@id"/>
			</xsl:if>
			<xsl:apply-templates/>
		</div>
	</xsl:template>
	
	
	<xsl:template match="table | thead | tbody | tfoot |
		col | colgroup | tr | th | td">
		<xsl:element name="{local-name()}">
			<xsl:apply-templates select="@*" mode="table-copy"/>			
			<xsl:apply-templates/>
		</xsl:element>
	</xsl:template>
	
	
	<xsl:template match="array/tbody">
		<table>
			<xsl:copy>
				<xsl:apply-templates select="@*" mode="table-copy"/>
				<xsl:apply-templates/>
			</xsl:copy>
		</table>
	</xsl:template>
	
	
	<xsl:template match="@*" mode="table-copy">
		<xsl:copy-of select="."/>
	</xsl:template>
	
	
	<xsl:template match="@content-type" mode="table-copy"/>
	
	<xsl:template match="fn"/>
	<xsl:template match="fn/p"/>
	
	
	<xsl:template match="xref">
		<xsl:choose>
			<xsl:when test="node()">
				<xsl:choose>
					<xsl:when test="@ref-type='fig' or @ref-type='table'">
						<a href="#{@rid}">
							<xsl:apply-templates/>
						</a>
					</xsl:when>
					<xsl:otherwise>
						<!--<xsl:text>[</xsl:text>-->
						<a href="#{@rid}">
							<xsl:apply-templates/>
						</a>
						<!--<xsl:text>]</xsl:text>-->
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="ref-list">
		<xsl:if test="title">
			<div class="ref-title">
				<xsl:apply-templates select="title/node()"/>
			</div>
		</xsl:if>
		<xsl:choose>
			<xsl:when test="ref/label">
				<ul style="list-style-type: none;">
					<xsl:apply-templates select="ref"/>
				</ul>
			</xsl:when>
			<xsl:otherwise>
				<ol>
					<xsl:apply-templates select="ref"/>
				</ol>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template match="ref">
		<li>
			<xsl:if test="@id">
				<xsl:attribute name="id" select="@id"/>
			</xsl:if>
			<xsl:apply-templates/>
		</li>
	</xsl:template>
	

</xsl:stylesheet>
